Welcome to |project| documentation!
===================================

.. sidebar-links::
   :home:
   :pypi:

.. toctree::
   :maxdepth: 1

   history

.. tidelift-referral-banner::

.. Disabled due to https://github.com/sphinx-doc/sphinx/issues/9704
.. .. automodule:: pip_run
..     :members:
..     :undoc-members:
..     :show-inheritance:

.. automodule:: pip_run.commands
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pip_run.deps
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pip_run.launch
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pip_run.scripts
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
